glance_store
============

The glance_store library supports the creation, deletion and gather of data
assets from/to a set of several, different, storage technologies

Contents
========

.. toctree::
   :maxdepth: 1

Release Notes
=============

0.0.1a1
-------

* Initial release of glance_store_.

.. _glance_store: https://wiki.openstack.org/wiki/Glance/Store

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

